#
# spec file for package tvbrowser
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tvbrowser
Summary:        Digital TV guide
License:        GPL-3.0+
Group:          Productivity/Multimedia/Other
Version:        3.4.1.0
Release:        4.2
Requires:       java >= 1.6
Url:            http://tv-browser.org
Source:         http://downloads.sourceforge.net/project/tvbrowser/TV-Browser%20Releases%20%28Java%206%20and%20higher%29/%{version}/%{name}_%{version}_src.zip
# TODO build from source, too
Source2:        http://www.tvbrowser.org/data/uploads/1372016422809_543/NewsPlugin.jar
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  java-devel
BuildRequires:  jpackage-utils
BuildRequires:  optipng
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
TV-Browser is Plugin based digital TV guide. Plugins can be installed with
the download function of TV-Browser.

%prep
cp %{S:2} .
%setup -q
dos2unix src/LICENSE.txt
find -name "*.png" | while read a; do
    optipng -o 5 "$a" || optipng -o 5 -fix "$a"
done

%build
%ant runtime-linux -Dnewsplugin.url=file:///%{_sourcedir}/NewsPlugin.jar

cat >tvbrowser <<'EOF'
#!/bin/sh

cd %{_javadir}/%{name}/ && \
    exec %{_bindir}/java \
        -Xms16m \
        -Xmx128m \
        -Djava.library.path=%{_javadir}/%{name} \
        -Dpropertiesfile=linux.properties \
        -jar tvbrowser.jar \
        "$@"
EOF

%install
export NO_BRP_CHECK_BYTECODE_VERSION="true"

install -D -p -m 755 tvbrowser %{buildroot}%{_bindir}/tvbrowser

mkdir -p %{buildroot}%{_javadir}/%{name}/
cp -r runtime/tvbrowser_linux/* %{buildroot}%{_javadir}/%{name}/

for size in 16 32 48 128; do
    (
        install -d %{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps/
        cd %{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps/
        ln -s %{_javadir}/%{name}/imgs/tvbrowser${size}.png tvbrowser.png
    )
done

%suse_update_desktop_file -c tvbrowser TV-Browser 'Digital TV Guide' tvbrowser tvbrowser AudioVideo TV Java

%fdupes %{buildroot}%{_javadir}

# TODO: JUnit is causing trouble
#%%check
#%%ant test

%clean
%ant clean

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root,-)
%doc ChangeLog.txt
%{_bindir}/tvbrowser
%{_javadir}/%{name}
%{_datadir}/applications/tvbrowser.desktop
%{_datadir}/icons/hicolor/*/apps/tvbrowser.png

%changelog
* Wed Dec 24 2014 dl8fcl@darc.de
- Update to version 3.4.1
- Only now and next programs in tray use filter settings value
- Allow instant advanced search for repetition search
- Make download handling more safe for not reacting servers (use threaded timeouts)
- Use at least picture with if available for picture display
- Speed up date change for program table
- Missing ProgramReceiceIfs are causing problems
- Create backup files for plugin data
- Better search for running and next program in tray
- Show channel logo in program panels
- Show restart entry in tray and after changing of locale
- Speed up marking
- Allow plugins to disable artificial plugin tree
- Create new favorite type for direct usage of filters
- Add fallback to auto download of plugin list
- Favorite exclusion window too small
- FilterManager should also handle ChannelGroups
- Show sort number in reminder and tray
- Internet connection check may have threading problem
- Add alphabetically sort function to filter tree
- Allow easy creation of channel filter
* Sat Sep 13 2014 ecsos@schirra.net
- Update to version 3.4.0.1
  Fix for TV-Browser might not start because of a configuration fault
  in the change of the channel charing of Comedy Central (de),
  VIVA (de) and Nickelodeon (de).
* Wed Jul  2 2014 dl8fcl@darc.de
- Update to version 3.4
  This version brings many new features that were often suggested like
  showing of program numbers or yers on our to do list. TV-Browser 3.4
  makes it easy to install new icon themes directly in TV-Browser.
  The Favorites can be viewed filtered and can be created as filter themself.
  TV-Browser 3.4 also fixes bugs so it will run even better than the
  previous version. We suggest to update to TV-Browser 3.4 as soon
  as possible, to profit from the new features an bug fixes.
- New Feature: Allow exclusions from favorites depending on the program category
- New Feature: Let plugins request to be click action plugin
- New Feature: detect configuration changes and reload settings
- New Feature: have generic filter possibility for plugin markers
- New Feature: "Add own URL-Handler for ""tvbrowser://"" - Links "
- New Feature: "New program fields ""part number"" and ""part total number"" "
- New Feature: Make display of data in program table customizable
- New Feature: have menu item to create a debug log
- New Feature: show warning for useless search option combination
- Improvement: Allow user to create filter for single Favorite
- Improvement: Provide way for plugins to communicate with each other in an
    indirect and save way
- Improvement: Allow filter usage in Favorite tab/dialog
- Improvement: Use time buttons for navigation in tab
- Improvement: Store paths relative if possible
- Improvement: show no warning for self-deleted data files
- Improvement: Store window position of reminder window
- Improvement: Don't remove channels automatically if they aren't available
- Improvement: have different additional info icon sets or allow changing those
    icons easily
- Improvement: Show Info when no channels are displayed
- Improvement: Redesign search dialog to make it more easy to use
- Bug: ConcurrentModificationException while update of TV Browser data
- Bug: Wrong default reminder time causes exception at opening settings
- Bug: Internet connection check dialog not removed for update started after
    startup
- Bug: Found favorites window opens with empty favorites
- Bug: ArrayIndexOutOfBoundsException whenn adding programs to ProgramList
- Bug: Timezone correction doesn't work properly in countries with different
    daylight saving time than the channel's country
- Bug: No more updates possible for a channelgroup when all mirrors changed
    since the last update
- Bug: empty plugin tree for some plugins if tvb started with closed plugin
    tree view
- Bug: Background color of currently running programs is displayed false
- Bug: Program data files are not treated if the next 7 days none of them exists
* Sat Feb  8 2014 mailaender@opensuse.org
- actually build from source
* Thu Nov 21 2013 dl8fcl@darc.de
- Update to version 3.3.3
- Make pictures of expired program darker not gray
- Show list of available plugins sorted alphabetically
- Allow plugins to prepare for data update
- Allow more than one episode number in field value (encoded)
- Plugins should be able to set custom program field type name.
- Highlight programs that run at time scroll time
- Plugin autoupdate is not shown
- Reminder recreated on favorite programs after update
- Make programs easy accessible that start at the same time on the
  same channel on the same date
- NPE in day selection calendar under Mac OS X
- Add warning if user deactiavtes the program table tab
- Original ProgramReceiveTargets are sorted by TV-Browser
- AIOOBE in ProgramList
- Filter changes should be trackable for plugins
- Date range for auto update changes with user initiated update
- Allow programs with duplicate start times
- option to enable/disable/configure highlighting of mouse menu colors
- Webpages in Plugin-Install-Dialog should be clickable
- Scroll to now after download (if there was no data available before)
- ask for minimize to tray on first close
* Mon Sep  2 2013 dl8fcl@darc.de
- Update to version 3.3.2
- Allow filter usage in search dialog
- Scroll automatically to next/previous day when mouse wheel is
  used in program table
* Thu Jul 18 2013 dl8fcl@darc.de
- Update to version 3.3.1
- Centralize mouse actions and make it more customizable
- Make filter editable from edit favorite dialog
- Search accepts German UND, ODER
- Description in FilterComponent classes, removed from settings panel
- Browsing with keyboard in filter-list
- Ability to remind after program start
* Sat Mar 23 2013 dl8fcl@darc.de
- Update to version 3.3
- new languages, Croatian and Greek. It is possible to install
  additional languages in the program settings.
- Date separators added for better orientation in the program lists
  of the plugins.
* Mon Oct 29 2012 meissner@suse.com
- use a URL for Source0.
* Sun Oct 28 2012 dl8fcl@darc.de
- Update to version 3.2.1
- TV-Browser 3.2.1 improves the performance, fixes some minor bugs
  and a mayor one that could destroy users filter components.
- TV-Browser 3.2 fixes bugs for better stability.
  New features are tab support, plugins can show their information
  the main window, many new predefined filters.
* Mon Dec  5 2011 gber@opensuse.org
- convert the included license to Unix line endings instead of
  shipping a separate copy of the license
- create a tailored launch script instead of relying on the
  guesswork in the upstream script and do not create symlinks
  bypassing the packaging system in %%post
- create desktop file via %%suse_update_desktop_file instead of
  patching the upstream one
- create explicit symlinks for application icons
- use %%desktop_database_post/un and %%icon_theme_cache_post/un to
  have the menu and icon caches updated on GTK-based desktops
- correct the RPM group
* Sun Oct 30 2011 dl8fcl@darc.de
- Update to version 3.1
* Fri Sep 16 2011 dl8fcl@darc.de 
- Update to version 3.0.2
- Description and LICENSE.txt updated
* Thu May 12 2011 dl8fcl@darc.de
- Update to version 3.0.1, tvbrowser-desktop fixed
* Sun Apr 11 2010 davejplater@gmail.com
- Update to version 2.7.5 added tvbrowser-2.7.5-desktop.patch
- TV-Browser 2.7.5 fixes one major and a few minor bugs.
  The major bug could prevent the german tv shows to be listed in
  the installation wizard.
- TV-Browser 2.7.4 fixes some bugs.
- TV-Browser 2.7.3 resolves mainly a bug in the data processing who
  led to an overload of the TV-Browser server at about 8 p.m.
  Additonally this update provides several minor bugfixes.
  We ask you emphatically to install TV-Browser 2.7.3 as soon as
  possible to decrease the load of the TV-Browser server.
* Thu Mar  5 2009 ro@suse.de
- added optipng to buildreq
* Sat Feb  7 2009 coolo@suse.de
- own the hicolor directories too
* Thu Jan 22 2009 tpatzig@suse.de
- update to version 2.7.2
  * new Java LookAndFeel Nimbus
  * stability and usabilty improvements
* Mon Mar  3 2008 tpatzig@suse.de
- update to version 2.6.3
  * a lot of Bugfixes
* Wed Nov 14 2007 tpatzig@suse.de
- update to version 2.6
  * Bugfixes
  * notification, when channels added or deleted
  * SMS/EMail notification via google calender
  * group your favorite tv-shows
  * automatic notifications for available plugin updates
  * new filter functionality
  * new settings
* Mon Aug  6 2007 tpatzig@suse.de
- added linux.properties
* Sat Aug  4 2007 tpatzig@suse.de
- fixed wrong permissions
* Sat Aug  4 2007 tpatzig@suse.de
- update to version 2.5.3
  * Bugfixes
  * automatically safe properties, when changed
  * automatic backup of the config file, to restore them if needed
* Tue Jul  3 2007 tpatzig@suse.de
- updated to version 2.5.2
- deleted libDesktopIndicator.so
* Mon Jan  8 2007 tpatzig@suse.de
- initial rpm build for TV-Browser 2.5
